summaryrefslogtreecommitdiff
path: root/src/mongo/db/s/balancer/balancer_defragmentation_policy.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/s/balancer/balancer_defragmentation_policy.h')
-rw-r--r--src/mongo/db/s/balancer/balancer_defragmentation_policy.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/s/balancer/balancer_defragmentation_policy.h b/src/mongo/db/s/balancer/balancer_defragmentation_policy.h
index 3358c6c79df..bfd81c9250f 100644
--- a/src/mongo/db/s/balancer/balancer_defragmentation_policy.h
+++ b/src/mongo/db/s/balancer/balancer_defragmentation_policy.h
@@ -76,11 +76,11 @@ public:
/**
* Pulls the next batch of actionable chunk migration requests, given the current internal state
* and the passed in list of unavaible shards.
* Every chunk migration request is then expected to be acknowledged by the balancer by issuing
* a call to applyActionResult() (declared in ActionsStreamPolicy)
*/
virtual MigrateInfoVector selectChunksToMove(OperationContext* opCtx,
- stdx::unordered_set<ShardId>* usedShards) = 0;
+ stdx::unordered_set<ShardId>* availableShards) = 0;
};
} // namespace mongo
@@ -76,11 +76,11 @@ public:
/**
* Pulls the next batch of actionable chunk migration requests, given the current internal state
- * and the passed in list of unavaible shards.
+ * and the passed in list of available shards.
* Every chunk migration request is then expected to be acknowledged by the balancer by issuing
* a call to applyActionResult() (declared in ActionsStreamPolicy)